import Long from "long";
import { ChannelCredentials, ChannelOptions, UntypedServiceImplementation, handleServerStreamingCall, handleUnaryCall, Client, CallOptions, ClientReadableStream, Metadata, ClientUnaryCall, ServiceError } from "@grpc/grpc-js";
import * as _m0 from "protobufjs/minimal";
import { DataEntry } from "../data_entry";
import { ContractTransferIn } from "../contract_transfer_in";
import { ContractAssetOperation } from "../contract_asset_operation";
export declare const protobufPackage = "wavesenterprise";
export interface CalculateAssetIdRequest {
    nonce?: number;
}
export interface ContractBalancesRequest {
    assetsIds?: string[];
}
export interface ContractBalancesResponse {
    assetsBalances?: ContractBalanceResponse[];
}
export interface ContractBalanceResponse {
    assetId?: string;
    amount?: Long;
    decimals?: number;
}
export interface ConnectionRequest {
    connectionId?: string;
}
export interface ContractTransactionResponse {
    transaction?: ContractTransaction;
    authToken?: string;
}
export interface ContractTransaction {
    id?: string;
    type?: number;
    sender?: string;
    senderPublicKey?: string;
    contractId?: string;
    params?: DataEntry[];
    fee?: Long;
    version?: number;
    proofs?: Uint8Array;
    timestamp?: Long;
    feeAssetId?: AssetId;
    payments?: ContractTransferIn[];
    createData?: CreateContractTransactionData | undefined;
    callData?: CallContractTransactionData | undefined;
}
export interface CreateContractTransactionData {
    image?: string;
    imageHash?: string;
    contractName?: string;
}
export interface CallContractTransactionData {
    contractVersion?: number;
}
export interface ExecutionSuccessRequest {
    txId?: string;
    results?: DataEntry[];
    assetOperations?: ContractAssetOperation[];
}
export interface ExecutionErrorRequest {
    txId?: string;
    message?: string;
    code?: number;
}
export interface CommitExecutionResponse {
}
export interface ContractKeysRequest {
    contractId?: string;
    limit?: number;
    offset?: number;
    matches?: string;
    keysFilter?: KeysFilter;
}
export interface KeysFilter {
    keys?: string[];
}
export interface ContractKeysResponse {
    entries?: DataEntry[];
}
export interface ContractKeyRequest {
    contractId?: string;
    key?: string;
}
export interface ContractKeyResponse {
    entry?: DataEntry;
}
export interface AssetId {
    value?: string;
}
export declare const CalculateAssetIdRequest: {
    encode(message: CalculateAssetIdRequest, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): CalculateAssetIdRequest;
    fromJSON(object: any): CalculateAssetIdRequest;
    toJSON(message: CalculateAssetIdRequest): unknown;
    fromPartial(object: DeepPartial<CalculateAssetIdRequest>): CalculateAssetIdRequest;
};
export declare const ContractBalancesRequest: {
    encode(message: ContractBalancesRequest, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): ContractBalancesRequest;
    fromJSON(object: any): ContractBalancesRequest;
    toJSON(message: ContractBalancesRequest): unknown;
    fromPartial(object: DeepPartial<ContractBalancesRequest>): ContractBalancesRequest;
};
export declare const ContractBalancesResponse: {
    encode(message: ContractBalancesResponse, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): ContractBalancesResponse;
    fromJSON(object: any): ContractBalancesResponse;
    toJSON(message: ContractBalancesResponse): unknown;
    fromPartial(object: DeepPartial<ContractBalancesResponse>): ContractBalancesResponse;
};
export declare const ContractBalanceResponse: {
    encode(message: ContractBalanceResponse, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): ContractBalanceResponse;
    fromJSON(object: any): ContractBalanceResponse;
    toJSON(message: ContractBalanceResponse): unknown;
    fromPartial(object: DeepPartial<ContractBalanceResponse>): ContractBalanceResponse;
};
export declare const ConnectionRequest: {
    encode(message: ConnectionRequest, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): ConnectionRequest;
    fromJSON(object: any): ConnectionRequest;
    toJSON(message: ConnectionRequest): unknown;
    fromPartial(object: DeepPartial<ConnectionRequest>): ConnectionRequest;
};
export declare const ContractTransactionResponse: {
    encode(message: ContractTransactionResponse, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): ContractTransactionResponse;
    fromJSON(object: any): ContractTransactionResponse;
    toJSON(message: ContractTransactionResponse): unknown;
    fromPartial(object: DeepPartial<ContractTransactionResponse>): ContractTransactionResponse;
};
export declare const ContractTransaction: {
    encode(message: ContractTransaction, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): ContractTransaction;
    fromJSON(object: any): ContractTransaction;
    toJSON(message: ContractTransaction): unknown;
    fromPartial(object: DeepPartial<ContractTransaction>): ContractTransaction;
};
export declare const CreateContractTransactionData: {
    encode(message: CreateContractTransactionData, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): CreateContractTransactionData;
    fromJSON(object: any): CreateContractTransactionData;
    toJSON(message: CreateContractTransactionData): unknown;
    fromPartial(object: DeepPartial<CreateContractTransactionData>): CreateContractTransactionData;
};
export declare const CallContractTransactionData: {
    encode(message: CallContractTransactionData, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): CallContractTransactionData;
    fromJSON(object: any): CallContractTransactionData;
    toJSON(message: CallContractTransactionData): unknown;
    fromPartial(object: DeepPartial<CallContractTransactionData>): CallContractTransactionData;
};
export declare const ExecutionSuccessRequest: {
    encode(message: ExecutionSuccessRequest, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): ExecutionSuccessRequest;
    fromJSON(object: any): ExecutionSuccessRequest;
    toJSON(message: ExecutionSuccessRequest): unknown;
    fromPartial(object: DeepPartial<ExecutionSuccessRequest>): ExecutionSuccessRequest;
};
export declare const ExecutionErrorRequest: {
    encode(message: ExecutionErrorRequest, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): ExecutionErrorRequest;
    fromJSON(object: any): ExecutionErrorRequest;
    toJSON(message: ExecutionErrorRequest): unknown;
    fromPartial(object: DeepPartial<ExecutionErrorRequest>): ExecutionErrorRequest;
};
export declare const CommitExecutionResponse: {
    encode(_: CommitExecutionResponse, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): CommitExecutionResponse;
    fromJSON(_: any): CommitExecutionResponse;
    toJSON(_: CommitExecutionResponse): unknown;
    fromPartial(_: DeepPartial<CommitExecutionResponse>): CommitExecutionResponse;
};
export declare const ContractKeysRequest: {
    encode(message: ContractKeysRequest, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): ContractKeysRequest;
    fromJSON(object: any): ContractKeysRequest;
    toJSON(message: ContractKeysRequest): unknown;
    fromPartial(object: DeepPartial<ContractKeysRequest>): ContractKeysRequest;
};
export declare const KeysFilter: {
    encode(message: KeysFilter, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): KeysFilter;
    fromJSON(object: any): KeysFilter;
    toJSON(message: KeysFilter): unknown;
    fromPartial(object: DeepPartial<KeysFilter>): KeysFilter;
};
export declare const ContractKeysResponse: {
    encode(message: ContractKeysResponse, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): ContractKeysResponse;
    fromJSON(object: any): ContractKeysResponse;
    toJSON(message: ContractKeysResponse): unknown;
    fromPartial(object: DeepPartial<ContractKeysResponse>): ContractKeysResponse;
};
export declare const ContractKeyRequest: {
    encode(message: ContractKeyRequest, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): ContractKeyRequest;
    fromJSON(object: any): ContractKeyRequest;
    toJSON(message: ContractKeyRequest): unknown;
    fromPartial(object: DeepPartial<ContractKeyRequest>): ContractKeyRequest;
};
export declare const ContractKeyResponse: {
    encode(message: ContractKeyResponse, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): ContractKeyResponse;
    fromJSON(object: any): ContractKeyResponse;
    toJSON(message: ContractKeyResponse): unknown;
    fromPartial(object: DeepPartial<ContractKeyResponse>): ContractKeyResponse;
};
export declare const AssetId: {
    encode(message: AssetId, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): AssetId;
    fromJSON(object: any): AssetId;
    toJSON(message: AssetId): unknown;
    fromPartial(object: DeepPartial<AssetId>): AssetId;
};
export declare const ContractServiceService: {
    readonly connect: {
        readonly path: "/wavesenterprise.ContractService/Connect";
        readonly requestStream: false;
        readonly responseStream: true;
        readonly requestSerialize: (value: ConnectionRequest) => Buffer;
        readonly requestDeserialize: (value: Buffer) => ConnectionRequest;
        readonly responseSerialize: (value: ContractTransactionResponse) => Buffer;
        readonly responseDeserialize: (value: Buffer) => ContractTransactionResponse;
    };
    readonly commitExecutionSuccess: {
        readonly path: "/wavesenterprise.ContractService/CommitExecutionSuccess";
        readonly requestStream: false;
        readonly responseStream: false;
        readonly requestSerialize: (value: ExecutionSuccessRequest) => Buffer;
        readonly requestDeserialize: (value: Buffer) => ExecutionSuccessRequest;
        readonly responseSerialize: (value: CommitExecutionResponse) => Buffer;
        readonly responseDeserialize: (value: Buffer) => CommitExecutionResponse;
    };
    readonly commitExecutionError: {
        readonly path: "/wavesenterprise.ContractService/CommitExecutionError";
        readonly requestStream: false;
        readonly responseStream: false;
        readonly requestSerialize: (value: ExecutionErrorRequest) => Buffer;
        readonly requestDeserialize: (value: Buffer) => ExecutionErrorRequest;
        readonly responseSerialize: (value: CommitExecutionResponse) => Buffer;
        readonly responseDeserialize: (value: Buffer) => CommitExecutionResponse;
    };
    readonly getContractKeys: {
        readonly path: "/wavesenterprise.ContractService/GetContractKeys";
        readonly requestStream: false;
        readonly responseStream: false;
        readonly requestSerialize: (value: ContractKeysRequest) => Buffer;
        readonly requestDeserialize: (value: Buffer) => ContractKeysRequest;
        readonly responseSerialize: (value: ContractKeysResponse) => Buffer;
        readonly responseDeserialize: (value: Buffer) => ContractKeysResponse;
    };
    readonly getContractKey: {
        readonly path: "/wavesenterprise.ContractService/GetContractKey";
        readonly requestStream: false;
        readonly responseStream: false;
        readonly requestSerialize: (value: ContractKeyRequest) => Buffer;
        readonly requestDeserialize: (value: Buffer) => ContractKeyRequest;
        readonly responseSerialize: (value: ContractKeyResponse) => Buffer;
        readonly responseDeserialize: (value: Buffer) => ContractKeyResponse;
    };
    readonly getContractBalances: {
        readonly path: "/wavesenterprise.ContractService/GetContractBalances";
        readonly requestStream: false;
        readonly responseStream: false;
        readonly requestSerialize: (value: ContractBalancesRequest) => Buffer;
        readonly requestDeserialize: (value: Buffer) => ContractBalancesRequest;
        readonly responseSerialize: (value: ContractBalancesResponse) => Buffer;
        readonly responseDeserialize: (value: Buffer) => ContractBalancesResponse;
    };
    readonly calculateAssetId: {
        readonly path: "/wavesenterprise.ContractService/CalculateAssetId";
        readonly requestStream: false;
        readonly responseStream: false;
        readonly requestSerialize: (value: CalculateAssetIdRequest) => Buffer;
        readonly requestDeserialize: (value: Buffer) => CalculateAssetIdRequest;
        readonly responseSerialize: (value: AssetId) => Buffer;
        readonly responseDeserialize: (value: Buffer) => AssetId;
    };
};
export interface ContractServiceServer extends UntypedServiceImplementation {
    connect: handleServerStreamingCall<ConnectionRequest, ContractTransactionResponse>;
    commitExecutionSuccess: handleUnaryCall<ExecutionSuccessRequest, CommitExecutionResponse>;
    commitExecutionError: handleUnaryCall<ExecutionErrorRequest, CommitExecutionResponse>;
    getContractKeys: handleUnaryCall<ContractKeysRequest, ContractKeysResponse>;
    getContractKey: handleUnaryCall<ContractKeyRequest, ContractKeyResponse>;
    getContractBalances: handleUnaryCall<ContractBalancesRequest, ContractBalancesResponse>;
    calculateAssetId: handleUnaryCall<CalculateAssetIdRequest, AssetId>;
}
export interface ContractServiceClient extends Client {
    connect(request: ConnectionRequest, options?: Partial<CallOptions>): ClientReadableStream<ContractTransactionResponse>;
    connect(request: ConnectionRequest, metadata?: Metadata, options?: Partial<CallOptions>): ClientReadableStream<ContractTransactionResponse>;
    commitExecutionSuccess(request: ExecutionSuccessRequest, callback: (error: ServiceError | null, response: CommitExecutionResponse) => void): ClientUnaryCall;
    commitExecutionSuccess(request: ExecutionSuccessRequest, metadata: Metadata, callback: (error: ServiceError | null, response: CommitExecutionResponse) => void): ClientUnaryCall;
    commitExecutionSuccess(request: ExecutionSuccessRequest, metadata: Metadata, options: Partial<CallOptions>, callback: (error: ServiceError | null, response: CommitExecutionResponse) => void): ClientUnaryCall;
    commitExecutionError(request: ExecutionErrorRequest, callback: (error: ServiceError | null, response: CommitExecutionResponse) => void): ClientUnaryCall;
    commitExecutionError(request: ExecutionErrorRequest, metadata: Metadata, callback: (error: ServiceError | null, response: CommitExecutionResponse) => void): ClientUnaryCall;
    commitExecutionError(request: ExecutionErrorRequest, metadata: Metadata, options: Partial<CallOptions>, callback: (error: ServiceError | null, response: CommitExecutionResponse) => void): ClientUnaryCall;
    getContractKeys(request: ContractKeysRequest, callback: (error: ServiceError | null, response: ContractKeysResponse) => void): ClientUnaryCall;
    getContractKeys(request: ContractKeysRequest, metadata: Metadata, callback: (error: ServiceError | null, response: ContractKeysResponse) => void): ClientUnaryCall;
    getContractKeys(request: ContractKeysRequest, metadata: Metadata, options: Partial<CallOptions>, callback: (error: ServiceError | null, response: ContractKeysResponse) => void): ClientUnaryCall;
    getContractKey(request: ContractKeyRequest, callback: (error: ServiceError | null, response: ContractKeyResponse) => void): ClientUnaryCall;
    getContractKey(request: ContractKeyRequest, metadata: Metadata, callback: (error: ServiceError | null, response: ContractKeyResponse) => void): ClientUnaryCall;
    getContractKey(request: ContractKeyRequest, metadata: Metadata, options: Partial<CallOptions>, callback: (error: ServiceError | null, response: ContractKeyResponse) => void): ClientUnaryCall;
    getContractBalances(request: ContractBalancesRequest, callback: (error: ServiceError | null, response: ContractBalancesResponse) => void): ClientUnaryCall;
    getContractBalances(request: ContractBalancesRequest, metadata: Metadata, callback: (error: ServiceError | null, response: ContractBalancesResponse) => void): ClientUnaryCall;
    getContractBalances(request: ContractBalancesRequest, metadata: Metadata, options: Partial<CallOptions>, callback: (error: ServiceError | null, response: ContractBalancesResponse) => void): ClientUnaryCall;
    calculateAssetId(request: CalculateAssetIdRequest, callback: (error: ServiceError | null, response: AssetId) => void): ClientUnaryCall;
    calculateAssetId(request: CalculateAssetIdRequest, metadata: Metadata, callback: (error: ServiceError | null, response: AssetId) => void): ClientUnaryCall;
    calculateAssetId(request: CalculateAssetIdRequest, metadata: Metadata, options: Partial<CallOptions>, callback: (error: ServiceError | null, response: AssetId) => void): ClientUnaryCall;
}
export declare const ContractServiceClient: {
    new (address: string, credentials: ChannelCredentials, options?: Partial<ChannelOptions>): ContractServiceClient;
    service: typeof ContractServiceService;
};
declare type Builtin = Date | Function | Uint8Array | string | number | boolean | undefined;
export declare type DeepPartial<T> = T extends Builtin ? T : T extends Long ? string | number | Long : T extends Array<infer U> ? Array<DeepPartial<U>> : T extends ReadonlyArray<infer U> ? ReadonlyArray<DeepPartial<U>> : T extends {} ? {
    [K in keyof T]?: DeepPartial<T[K]>;
} : Partial<T>;
export {};
