import Long from "long";
import { ChannelCredentials, ChannelOptions, UntypedServiceImplementation, handleUnaryCall, Client, ClientUnaryCall, Metadata, CallOptions, ServiceError } from "@grpc/grpc-js";
import * as _m0 from "protobufjs/minimal";
import { CryptoType, ConsensusType, PkiMode } from "../constants";
import { Duration } from "../google/protobuf/duration";
import { Empty } from "../google/protobuf/empty";
export declare const protobufPackage = "wavesenterprise";
export interface NodeConfigResponse {
    version?: string;
    cryptoType?: CryptoType;
    chainId?: number;
    consensus?: ConsensusType;
    minimumFee?: {
        [key: string]: Long;
    };
    additionalFee?: {
        [key: string]: Long;
    };
    maxTransactionsInMicroBlock?: number;
    minMicroBlockAge?: Duration;
    microBlockInterval?: Duration;
    pkiMode?: PkiMode;
    requiredOids?: string[];
    crlCheckEnabled?: boolean;
    poaRoundInfo?: PoaRoundInfo | undefined;
    posRoundInfo?: PosRoundInfo | undefined;
}
export interface NodeConfigResponse_MinimumFeeEntry {
    key: string;
    value: Long;
}
export interface NodeConfigResponse_AdditionalFeeEntry {
    key: string;
    value: Long;
}
export interface PoaRoundInfo {
    roundDuration?: Duration;
    syncDuration?: Duration;
}
export interface PosRoundInfo {
    averageBlockDelay?: Duration;
}
export interface AddressWithPubKeyResponse {
    address?: string;
    publicKey?: string;
}
export declare const NodeConfigResponse: {
    encode(message: NodeConfigResponse, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): NodeConfigResponse;
    fromJSON(object: any): NodeConfigResponse;
    toJSON(message: NodeConfigResponse): unknown;
    fromPartial(object: DeepPartial<NodeConfigResponse>): NodeConfigResponse;
};
export declare const NodeConfigResponse_MinimumFeeEntry: {
    encode(message: NodeConfigResponse_MinimumFeeEntry, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): NodeConfigResponse_MinimumFeeEntry;
    fromJSON(object: any): NodeConfigResponse_MinimumFeeEntry;
    toJSON(message: NodeConfigResponse_MinimumFeeEntry): unknown;
    fromPartial(object: DeepPartial<NodeConfigResponse_MinimumFeeEntry>): NodeConfigResponse_MinimumFeeEntry;
};
export declare const NodeConfigResponse_AdditionalFeeEntry: {
    encode(message: NodeConfigResponse_AdditionalFeeEntry, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): NodeConfigResponse_AdditionalFeeEntry;
    fromJSON(object: any): NodeConfigResponse_AdditionalFeeEntry;
    toJSON(message: NodeConfigResponse_AdditionalFeeEntry): unknown;
    fromPartial(object: DeepPartial<NodeConfigResponse_AdditionalFeeEntry>): NodeConfigResponse_AdditionalFeeEntry;
};
export declare const PoaRoundInfo: {
    encode(message: PoaRoundInfo, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): PoaRoundInfo;
    fromJSON(object: any): PoaRoundInfo;
    toJSON(message: PoaRoundInfo): unknown;
    fromPartial(object: DeepPartial<PoaRoundInfo>): PoaRoundInfo;
};
export declare const PosRoundInfo: {
    encode(message: PosRoundInfo, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): PosRoundInfo;
    fromJSON(object: any): PosRoundInfo;
    toJSON(message: PosRoundInfo): unknown;
    fromPartial(object: DeepPartial<PosRoundInfo>): PosRoundInfo;
};
export declare const AddressWithPubKeyResponse: {
    encode(message: AddressWithPubKeyResponse, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): AddressWithPubKeyResponse;
    fromJSON(object: any): AddressWithPubKeyResponse;
    toJSON(message: AddressWithPubKeyResponse): unknown;
    fromPartial(object: DeepPartial<AddressWithPubKeyResponse>): AddressWithPubKeyResponse;
};
export declare const NodeInfoServiceService: {
    readonly nodeConfig: {
        readonly path: "/wavesenterprise.NodeInfoService/NodeConfig";
        readonly requestStream: false;
        readonly responseStream: false;
        readonly requestSerialize: (value: Empty) => Buffer;
        readonly requestDeserialize: (value: Buffer) => Empty;
        readonly responseSerialize: (value: NodeConfigResponse) => Buffer;
        readonly responseDeserialize: (value: Buffer) => NodeConfigResponse;
    };
    readonly nodeOwner: {
        readonly path: "/wavesenterprise.NodeInfoService/NodeOwner";
        readonly requestStream: false;
        readonly responseStream: false;
        readonly requestSerialize: (value: Empty) => Buffer;
        readonly requestDeserialize: (value: Buffer) => Empty;
        readonly responseSerialize: (value: AddressWithPubKeyResponse) => Buffer;
        readonly responseDeserialize: (value: Buffer) => AddressWithPubKeyResponse;
    };
};
export interface NodeInfoServiceServer extends UntypedServiceImplementation {
    nodeConfig: handleUnaryCall<Empty, NodeConfigResponse>;
    nodeOwner: handleUnaryCall<Empty, AddressWithPubKeyResponse>;
}
export interface NodeInfoServiceClient extends Client {
    nodeConfig(request: Empty, callback: (error: ServiceError | null, response: NodeConfigResponse) => void): ClientUnaryCall;
    nodeConfig(request: Empty, metadata: Metadata, callback: (error: ServiceError | null, response: NodeConfigResponse) => void): ClientUnaryCall;
    nodeConfig(request: Empty, metadata: Metadata, options: Partial<CallOptions>, callback: (error: ServiceError | null, response: NodeConfigResponse) => void): ClientUnaryCall;
    nodeOwner(request: Empty, callback: (error: ServiceError | null, response: AddressWithPubKeyResponse) => void): ClientUnaryCall;
    nodeOwner(request: Empty, metadata: Metadata, callback: (error: ServiceError | null, response: AddressWithPubKeyResponse) => void): ClientUnaryCall;
    nodeOwner(request: Empty, metadata: Metadata, options: Partial<CallOptions>, callback: (error: ServiceError | null, response: AddressWithPubKeyResponse) => void): ClientUnaryCall;
}
export declare const NodeInfoServiceClient: {
    new (address: string, credentials: ChannelCredentials, options?: Partial<ChannelOptions>): NodeInfoServiceClient;
    service: typeof NodeInfoServiceService;
};
declare type Builtin = Date | Function | Uint8Array | string | number | boolean | undefined;
export declare type DeepPartial<T> = T extends Builtin ? T : T extends Long ? string | number | Long : T extends Array<infer U> ? Array<DeepPartial<U>> : T extends ReadonlyArray<infer U> ? ReadonlyArray<DeepPartial<U>> : T extends {} ? {
    [K in keyof T]?: DeepPartial<T[K]>;
} : Partial<T>;
export {};
